@@ -1,4 +1,4 @@
-/*  Copyright 1996-2004,2007-2009 Alain Knaff.
+/*  Copyright 1996-2004,2007-2010 Alain Knaff.
  *  This file is part of mtools.
  *
  *  Mtools is free software: you can redistribute it and/or modify
@@ -50,6 +50,7 @@ static const struct dispatch {
 	{"mmove",mmove, 0},
 	{"mren",mmove, 1},
 	{"mshowfat", mshowfat, 0},
+	{"mshortname", mshortname, 0},
 	{"mtoolstest", mtoolstest, 0},
 	{"mtype",mcopy, 1},
 	{"mwrite",mcopy, 0},
@@ -77,10 +78,10 @@ int main(int argc,char **argv)
 /*#define PRIV_TEST*/
 
 #ifdef PRIV_TEST
-	{ 
+	{
 		int euid;
 		char command[100];
-	
+
 		printf("INIT: %d %d\n", getuid(), geteuid());
 		drop_privs();
 		printf("DROP: %d %d\n", getuid(), geteuid());
@@ -104,7 +105,7 @@ int main(int argc,char **argv)
 
 #ifdef __EMX__
        _wildcard(&argc,&argv);
-#endif 
+#endif
 
 
 	/* check whether the compiler lays out structures in a sane way */
@@ -131,7 +132,7 @@ int main(int argc,char **argv)
 	** Mainly done for the BeOS, which doesn't support links yet.
 	*/
 
-	if(argc >= 3 && 
+	if(argc >= 3 &&
 	   !strcmp(argv[1], "-c") &&
 	   !strcmp(name, "mtools")) {
 		argc-=2;
@@ -142,9 +143,9 @@ int main(int argc,char **argv)
 
 
 	/* print the version */
-	if(argc >= 2 && 
+	if(argc >= 2 &&
 	   (strcmp(argv[1], "-V") == 0 || strcmp(argv[1], "--version") ==0)) {
-		printf("%s (GNU mtools) %s\n", 
+		printf("%s (GNU mtools) %s\n",
 		       name, mversion);
 		printf("configured with the following options: ");
 #ifdef USE_XDF
